@@ -1,5 +1,3 @@
-var GlobalDrag;
-
 // gbTurnOff turns off any "All On" or "All Off" checkboxes which are checked.
 function gbTurnOff (section_name) {
   if ($(section_name+"_a"))
@@ -14,47 +12,49 @@ function gbCheck (button,state) {
   if (!$(a))
     return false;
   
-  var checkboxes = $(a).select("input");
+  var checkboxes = $(a).select(".track_title");
   if (!checkboxes)
     return false;
 
-  var added_tracks = false;
-
-  if (state == 1) {
-    var track_names = new Array();
-    for (var i=0; i<checkboxes.length; i++) {
-      checkboxes[i].checked=state;
-      track_names.push(checkboxes[i].value)
-    }
-    added_tracks = Controller.add_tracks(track_names);
-  }
+  //  var track_names = new Array();
   for (var i=0; i<checkboxes.length; i++) {
-      checkboxes[i].checked = state;
-      gbToggleTrack(checkboxes[i]);
+      var track_name = checkboxes[i].id.split('_',1);
+      ShowHideTrack(track_name,state);
   }
+  //  var added_tracks = Controller.add_tracks(track_names);
   gbTurnOff(a);
   button.checked = true;
   updateList($(a));
   return true;
 }
 
-function gbToggleTrack (button) {
-  var track_name = button.value;
-  var visible    = button.checked;
-  ShowHideTrack(track_name,visible);
+function gbToggleTrack (track_name) {
+    ShowHideTrack(track_name);
 }
 
 // ShowHideTrack toggles the visibility of "track", based on the "visible" flag.
 function ShowHideTrack(track_name,visible) {
-  var track_link  = $('link_'+track_name);
-  var ancestor   = track_link.ancestors().find(
+  var track_title = $(track_name+'_check');
+  var track_img   = $(track_name+'_img');
+  var ancestor    = track_title.ancestors().find(
 					function (el) {
 					    return el.nodeName == 'TD'
 					});
-  if (visible)
+  if (visible == null) {
+      visible = !ancestor.hasClassName('activeTrack');
+  }
+  if (visible) {
       ancestor.addClassName('activeTrack');
-  else
+      track_title.addClassName('activeTrack');
+      track_img.src=Controller.button_url('check.png');
+  }  else {
       ancestor.removeClassName('activeTrack');
+      track_title.removeClassName('activeTrack');
+      track_img.src=Controller.button_url('empty.png');
+  }
+
+  checkSummaries();
+  _checkAllToggles(track_title);
 
   if (visible && !Controller.track_exists(track_name)) {
       Controller.add_track(track_name);
@@ -69,7 +69,6 @@ function ShowHideTrack(track_name,visible) {
            if (element.style.display == "none") { 
              element.style.display="block";
              Controller.set_track_visibility(gbtrack.track_id, 1);
-	     
            }
        }
        else {
@@ -79,10 +78,6 @@ function ShowHideTrack(track_name,visible) {
           }
        }
      });
-
-     if ($(track_name+'_check') == null)
-         track_name = track_name.sub(/:(overview|region|detail)$/,'');
-     $(track_name + '_check').checked = visible ? true : false;
 }
 
 function update_segment (formdata) {
@@ -100,24 +95,3 @@ function update_segment (formdata) {
                   );
 }
 
-function create_drag (div_name) {
-   GlobalDrag = div_name;
-   Sortable.create(
-		  div_name,
-		  {
-		      tag:     'div',
-		      constraint:  'vertical',
-  		      only:    'track',
-		      handle:  'drag_region',
-		      scroll:   window,
-		      onUpdate: function() {
-		      var items   = $(div_name).select('[class="track"]');
-		      var ids     = items.map(function(e){return e.id});
-		      ids         = ids.map(function(i) {return 'label[]='+escape(i.sub(/^track_/,''))});
-		      var postData= ids.join('&')+';action=change_track_order';
-		      new Ajax.Request(document.URL,{method:'post',postBody:postData});
-		    }
-		  }
-		 );
-}
-
